@@ -286,7 +286,7 @@ def make_customs(path):
     import inquirer
     from git import Repo
     from .tools import copy_dir_contents
-    dir = Path(os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe()))))
+    dir = get_template_dir()
     src_dir = dir / 'customs_template'
 
     def _floatify(x):
@@ -323,11 +323,30 @@ def make_customs(path):
     subprocess.call(["git", "add", "."], cwd=path)
     subprocess.call(["git", "commit", "-am", "init"], cwd=path)
     subprocess.call(['gimera', 'apply', '--update'], cwd=path)
+    if os.getenv("SUDO_USER"):
+        subprocess.run(["chown", os.environ['SUDO_USER'], ".", '-R'], cwd=path)
+        subprocess.run(["chgrp", os.environ['SUDO_USER'], ".", '-R'], cwd=path)
+
 
     click.secho("Initialized - please call following now.", fg='green')
     click.secho("odoo db reset", fg='green')
     sys.exit(0)
 
+def get_template_dir():
+    path = Path(os.path.expanduser("~/.odoo/templates"))
+    url = 'https://github.com/marcwimmer/wodoo-templates'
+    path.parent.mkdir(parents=True, exist_ok=True)
+    if not path.exists():
+        subprocess.check_call(['git', 'clone', url, path])
+    try:
+        subprocess.check_call(['git', 'pull'], cwd=path)
+    except:
+        if path.exists():
+            shutil.rmtree(path)
+        subprocess.check_call(['git', 'clone', url, path])
+    return path
+
+
 def make_module(parent_path, module_name):
     """
     Creates a new odoo module based on a provided template.
@@ -340,7 +359,8 @@ def make_module(parent_path, module_name):
         raise Exception("Path already exists: {}".format(complete_path))
     odoo_root = os.environ['ODOO_HOME']
 
-    shutil.copytree(str(Path(odoo_root) / 'module_template' / str(version)), complete_path)
+    source = get_template_dir()
+    shutil.copytree(str(source / 'module_template' / str(version)), complete_path)
     for root, dirs, _files in os.walk(complete_path):
         if '.git' in dirs:
             dirs.remove('.git')
@@ -358,6 +378,11 @@ def make_module(parent_path, module_name):
     modules.append(module_name)
     m['install'] = modules
 
+    # correct file permissions
+    if os.getenv("SUDO_USER"):
+        subprocess.run(["chown", os.environ['SUDO_USER'], ".", '-R'], cwd=complete_path)
+        subprocess.run(["chgrp", os.environ['SUDO_USER'], ".", '-R'], cwd=complete_path)
+
 def restart(quick):
     if quick:
         write_debug_instruction('quick_restart')
